package org.springblade.modules.superloan.controller;

import io.swagger.annotations.Api;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import javax.validation.Valid;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.common.constant.CommonConstant;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;

import org.springblade.modules.superloan.entity.SuperLoanUserEntity;
import org.springblade.modules.superloan.vo.SuperLoanUserVO;
import org.springblade.modules.superloan.wrapper.SuperLoanUserWrapper;
import org.springblade.modules.superloan.service.ISuperLoanUserService;


/**
 *  控制器
 *
 * @author Chill
 */
@RestController
@AllArgsConstructor
@RequestMapping("/blade-superloan/superloanUser")
@Api(value = "", tags = "")
public class SuperLoanUserController extends BladeController {

	private ISuperLoanUserService superloanUserService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入superloanUser")
	public R<SuperLoanUserEntity> detail(SuperLoanUserEntity superloanUser) {
		SuperLoanUserEntity detail = superloanUserService.getOne(Condition.getQueryWrapper(superloanUser));
		return R.data(detail);
	}

	/**
	 * 分页 代码自定义代号
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入superloanUser")
	public R<IPage<SuperLoanUserEntity>> list(SuperLoanUserEntity superloanUser, Query query) {
		IPage<SuperLoanUserEntity> pages = superloanUserService.page(Condition.getPage(query), Condition.getQueryWrapper(superloanUser));
		return R.data(pages);
	}

	/**
	 * 新增 代码自定义代号
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入superloanUser")
	public R save(@Valid @RequestBody SuperLoanUserEntity superloanUser) {
		return R.status(superloanUserService.save(superloanUser));
	}

	/**
	 * 修改 代码自定义代号
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入superloanUser")
	public R update(@Valid @RequestBody SuperLoanUserEntity superloanUser) {
		return R.status(superloanUserService.updateById(superloanUser));
	}

	/**
	 * 新增或修改 代码自定义代号
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入superloanUser")
	public R submit(@Valid @RequestBody SuperLoanUserEntity superloanUser) {
		return R.status(superloanUserService.saveOrUpdate(superloanUser));
	}


	/**
	 * 删除 代码自定义代号
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(superloanUserService.deleteLogic(Func.toLongList(ids)));
	}

}
